@@ -181,7 +181,10 @@ class CliApplication():
         else:
             try:
                 codefile.close()
-                print("Server error!", response.json())
+                data = response.json()
+                if data["code" == 100]:
+                    print(data["result"]["message"])
+                # print("Server error!", response.json())
             except ValueError:
                 print("Server response have not data in it.")
                 sys.exit()
